Python ThreatKB API
===================

.. image:: https://travis-ci.org/InQuest/python-threatkb.svg?branch=master
    :target: https://travis-ci.org/InQuest/python-threatkb
    :alt: Build Status
.. image:: https://readthedocs.org/projects/threatkb/badge/?version=latest
    :target: http://threatkb.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://api.codacy.com/project/badge/Grade/c8e20eedc34f449989485177c5e8268e
    :target: https://app.codacy.com/app/InQuest/python-threatkb
    :alt: Code Health
.. image:: https://api.codacy.com/project/badge/Coverage/c8e20eedc34f449989485177c5e8268e
    :target: https://app.codacy.com/app/InQuest/python-threatkb
    :alt: Test Coverage
.. image:: http://img.shields.io/pypi/v/threatkb.svg
    :target: https://pypi.python.org/pypi/threatkb
    :alt: PyPi Version

Python library and command-line tool for `InQuest ThreatKB`_.

Contributing
------------

PRs and Issues_ are always welcome. The library is released under a "BSD-New"
(aka "BSD 3-Clause") license.

.. _InQuest ThreatKB: https://github.com/InQuest/ThreatKB
.. _Issues: https://github.com/inquest/python-threatkb/issues
